@@ -321,7 +321,7 @@ public class GathererThread extends Thread {
 			if (recordSet != null) {
 				recordSet.clear();
 				this.channel.remove(recordSet.getName());
-				if (Thread.currentThread().getId() == this.application.getThreadId()) {
+				if (Thread.currentThread().threadId() == this.application.getThreadId()) {
 					this.application.getMenuToolBar().updateRecordSetSelectCombo();
 					this.application.updateStatisticsData();
 					this.application.updateDataTable(this.recordSetKey, true);
